==> alg-common-1.19.7-20190827.095037-1-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/TestMXX.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Map;

public class TestMXX {
    public static void main(String[] args) {

        OrientInfo OrientInfo1=new OrientInfo();
        OrientInfo1.setAdvertId(1L);
        OrientInfo1.setOrientId(1L);
        OrientInfo1.setAppOrientCvrDay(0.04);

        OrientInfo1.setCost20d(8861.0);      //20天消耗
        OrientInfo1.setCvrSet(Arrays.asList(0.010753,0.0,0.0,0.0,0.0));
        OrientInfo1.setBiasSet(Arrays.asList(0.116366,99.0,99.0,99.0,99.0));

        OrientInfo1.importantAppAfee=null;   //重点媒体转化出价  默认null
        OrientInfo1.cvrType=0;   //cvr类型   默认为前端cvr
        OrientInfo1.releaseTarget=3;

        OrientInfo1.setManageType(2);
        OrientInfo1.setChargeType(2);
        OrientInfo1.setTarget(100L);
        OrientInfo1.setFee(100L);
        OrientInfo1.setOrientCostG7d(8861.0);
        OrientInfo1.setOrientCostG1d(8861.0);
        OrientInfo1.setOrientConvertG1d(0.0);
        OrientInfo1.setSlotOrientationCost(0.0);
        OrientInfo1.setSlotAdvertConvert(0.0);
        OrientInfo1.setSlotAdvertCost(0.0);
        OrientInfo1.setSlotOrientationConvert(0.0);
        OrientInfo1.setAppOrientationCost(0.0);
        OrientInfo1.setAppOrientationConvert(0.0);
        OrientInfo1.setFuseWhite(true);
        HelpMeasureResult h1 = new HelpMeasureResult();
        h1.setExpand(true);
        h1.setIsReorient(1.2);
        OrientInfo1.setHelpMeasureResult(h1);

        OrientInfo OrientInfo2=new OrientInfo();
        OrientInfo2.setAdvertId(22L);
        OrientInfo2.setOrientId(22L);
        OrientInfo2.setAppOrientCvrDay(0.4);

        OrientInfo2.setCost20d(900000.0);      //20天消耗
        OrientInfo2.setCvrSet(Arrays.asList(0.3,0.2,0.05,0.02,0.01));
        OrientInfo2.setBiasSet(Arrays.asList(1.5,1.4,1.1,1.0,1.6));

        OrientInfo2.importantAppAfee=null;   //重点媒体转化出价  默认null
        OrientInfo2.cvrType=0;   //cvr类型   默认为前端cvr
        OrientInfo2.releaseTarget=3;

        OrientInfo2.setManageType(2);
        OrientInfo2.setChargeType(2);
        OrientInfo2.setTarget(2000L);
        OrientInfo2.setFee(2000L);
        OrientInfo2.setOrientCostG7d(0.0);
        OrientInfo2.setOrientCostG1d(0.0);
        OrientInfo2.setOrientConvertG1d(0.0);
        OrientInfo2.setSlotAdvertConvert(0.0);
        OrientInfo2.setSlotAdvertCost(0.0);
        OrientInfo2.setSlotOrientationCost(0.0);
        OrientInfo2.setSlotOrientationConvert(0.0);
        OrientInfo2.setAppOrientationCost(0.0);
        OrientInfo2.setAppOrientationConvert(0.0);
        OrientInfo2.setFuseWhite(true);
        HelpMeasureResult h2 = new HelpMeasureResult();
        OrientInfo2.setHelpMeasureResult(h2);

        Collection<OrientInfo> orientlist=new ArrayList<>();
        orientlist.add(OrientInfo1);
        orientlist.add(OrientInfo2);

        TrusteeshipParams trusteeshipParams=new TrusteeshipParams();

        TrusteeshipParams.ReleaseTarget3FeedBackParams feedBackParams = trusteeshipParams.getReleaseTarget3feedBackParams();
        TrusteeshipParams.ReleaseTarget3SlotRecommendParams slotRecommendParams=trusteeshipParams.getReleaseTarget3slotRecommendParams();

        Map<ResultType, Collection<AdvertOrientInfo>> result=SlotRecommender.recommend(orientlist,11L,trusteeshipParams);
        System.out.println(trusteeshipParams);
        System.out.println(result);


    }

}

==> alg-common-1.19.27-20191030.055945-1-sources.jar: cn/com/duiba/nezha/alg/common/model/pacing/TestMXX.java <==
package cn.com.duiba.nezha.alg.common.model.pacing;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Map;

public class TestMXX {
    public static void main(String[] args) {

        OrientInfo OrientInfo1=new OrientInfo();
        OrientInfo1.setAdvertId(1L);
        OrientInfo1.setOrientId(1L);
        OrientInfo1.setAppOrientCvrDay(0.04);

        OrientInfo1.setCost20d(200000.0);      //20天消耗
        OrientInfo1.setCvrSet(Arrays.asList(0.05, 0.0, 0.0, 0.0, 0.0));
        OrientInfo1.setBiasSet(Arrays.asList(0.05,99.0, 99.0, 99.0,99.0));
        OrientInfo1.setCost7d(10000.0);
        OrientInfo1.setCorrelationCoefficient(0.07);
        OrientInfo1.importantAppAfee=1000L;   //重点媒体转化出价  默认null
        OrientInfo1.cvrType=3;   //cvr类型   默认为前端cvr
        OrientInfo1.releaseTarget=1;

        OrientInfo1.setManageType(2);
        OrientInfo1.setChargeType(2);
        OrientInfo1.setTarget(1000L);
        OrientInfo1.setFee(100L);
        OrientInfo1.setOrientCostG7d(0.0);
        OrientInfo1.setOrientCostG1d(100000.0);
        OrientInfo1.setOrientConvertG1d(90.0);
        OrientInfo1.setSlotOrientationCost(0.0);
        OrientInfo1.setSlotAdvertConvert(0.0);
        OrientInfo1.setSlotAdvertCost(0.0);
        OrientInfo1.setSlotOrientationConvert(0.0);
        OrientInfo1.setAppOrientationCost(0.0);
        OrientInfo1.setAppOrientationConvert(0.0);
        OrientInfo1.setFuseWhite(true);
        HelpMeasureResult h1 = new HelpMeasureResult();
        h1.setExpand(true);
        h1.setIsReorient(1.2);
        OrientInfo1.setHelpMeasureResult(h1);

        OrientInfo OrientInfo2=new OrientInfo();
        OrientInfo2.setAdvertId(22L);
        OrientInfo2.setOrientId(22L);
        OrientInfo2.setAppOrientCvrDay(0.4);

        OrientInfo2.setCost20d(900000.0);      //20天消耗
        OrientInfo2.setCvrSet(Arrays.asList(0.3,0.2,0.05,0.02,0.01));
        OrientInfo2.setBiasSet(Arrays.asList(1.5,1.4,1.1,1.0,1.6));
        OrientInfo2.setCost7d(0.0);
        OrientInfo2.setCorrelationCoefficient(0.09);

        OrientInfo2.importantAppAfee=null;   //重点媒体转化出价  默认null
        OrientInfo2.cvrType=3;   //cvr类型   默认为前端cvr
        OrientInfo2.releaseTarget=1;

        OrientInfo2.setManageType(2);
        OrientInfo2.setChargeType(2);
        OrientInfo2.setTarget(1000L);
        OrientInfo2.setFee(2000L);
        OrientInfo2.setOrientCostG7d(0.0);
        OrientInfo2.setOrientCostG1d(100000.0);
        OrientInfo2.setOrientConvertG1d(100.0);
        OrientInfo2.setSlotAdvertConvert(0.0);
        OrientInfo2.setSlotAdvertCost(0.0);
        OrientInfo2.setSlotOrientationCost(0.0);
        OrientInfo2.setSlotOrientationConvert(0.0);
        OrientInfo2.setAppOrientationCost(0.0);
        OrientInfo2.setAppOrientationConvert(0.0);
        OrientInfo2.setFuseWhite(true);
        HelpMeasureResult h2 = new HelpMeasureResult();
        h2.setExpand(true);
        h2.setOrientRatioWeight(1.2);
        OrientInfo2.setHelpMeasureResult(h2);

        Collection<OrientInfo> orientlist=new ArrayList<>();
        orientlist.add(OrientInfo1);
        orientlist.add(OrientInfo2);

        TrusteeshipParams trusteeshipParams=new TrusteeshipParams();

        TrusteeshipParams.ReleaseTarget3FeedBackParams feedBackParams = trusteeshipParams.getReleaseTarget3feedBackParams();

        TrusteeshipParams.ReleaseTarget1SlotRecommendParams slotRecommendParams=trusteeshipParams.getReleaseTarget1slotRecommendParams();
        slotRecommendParams.setStartFactor(1.0);
        slotRecommendParams.setCpaHisCorrCoeffRatioFactor(0.45);
        slotRecommendParams.setCpaNotHisCorrCoeffThreshod(4.0);
        slotRecommendParams.setCpaHisCorrCoeffThreshod(4.0);
//        slotRecommendParams.setCpaHisCorrCoeffRatioFactor(1.0);

        trusteeshipParams.setReleaseTarget1slotRecommendParams(slotRecommendParams);
        Map<ResultType, Collection<AdvertOrientInfo>> result=SlotRecommender.recommend(orientlist,11L,trusteeshipParams);
        System.out.println(trusteeshipParams);
        System.out.println(result);


    }

}
